@@ -200,9 +200,7 @@ formants. Then harmonics are found in the spectrum of the residual signal.
 Drugman and Alwan found that this technique provides an estimate of F0 that is 
 robust when the audio signal is corrupted by noise. 
 
-The f0 range is adaptively adjusted and the result of this is returned by the function.
-If you have multiple recordings of the same person, it would speed things up to 
-make use of this return value.
+The f0 range is adaptively adjusted.
 
 Probability of voicing is given from a logistic regression formula using `rms` and `srh` 
 trained to predict the voicing state as determined by EGG data using the function `phonlab.egg_to_oq()` 
@@ -219,8 +217,6 @@ Parameters
         The lowest and highest values to consider in pitch tracking. This algorithm is quite sensitive to the values given in this setting.
     isResidual : Boolean, default = False
         If the input array is a residual signal
-    l : float, default = 0.06
-        Length of the pitch analysis window in seconds. The default is 60 milliseconds.  
     s : float, default = 0.005
         "Hop" interval between successive analysis windows. The default is 5 milliseconds
 
